"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MongoDb = require("mongodb");
const JsonEncoder_1 = require("../lib/JsonEncoder");
class Collection {
    get name() {
        return this._collection.collectionName;
    }
    constructor(collection) {
        this._collection = collection;
    }
    async findOne(document) {
        const obj = await this._collection.findOne({
            _id: new MongoDb.ObjectId(document)
        });
        return JsonEncoder_1.default.encode(obj);
    }
    find(query, sort, limit, skip) {
        return this._collection.find(JsonEncoder_1.default.decode(query))
            .sort(JsonEncoder_1.default.decode(sort))
            .limit(limit)
            .skip(skip)
            .map((obj) => {
            return JsonEncoder_1.default.encode(obj);
        })
            .toArray();
    }
    async updateOne(document, newObj) {
        const update = JsonEncoder_1.default.decode(newObj);
        await this._collection.replaceOne({
            _id: new MongoDb.ObjectId(document)
        }, update);
        return JsonEncoder_1.default.encode(update);
    }
    async removeOne(document) {
        await this._collection.deleteOne({
            _id: new MongoDb.ObjectId(document)
        });
    }
    count(query) {
        return this._collection.estimatedDocumentCount(JsonEncoder_1.default.decode(query));
        // return this._collection.countDocuments(JsonEncoder.decode(query));
    }
    async toJson() {
        const stats = await this._collection.stats();
        return {
            // ns:             stats.ns,
            name: this.name,
            size: (stats.storageSize || 0) + (stats.totalIndexSize || 0),
            dataSize: stats.size,
            count: stats.count,
            avgObjSize: stats.avgObjSize || 0,
            storageSize: stats.storageSize || 0,
            capped: stats.capped,
            nIndexes: stats.nindexes,
            totalIndexSize: stats.totalIndexSize || 0,
            indexSizes: stats.indexSizes
        };
    }
}
exports.Collection = Collection;
