"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const util = require("util");
const Nedb = require("nedb");
const DEFAULT_HOST = 'localhost:27017';
const DATABASE_FILE = 'hosts.db';
class HostsManager {
    promise(fn) {
        return util.promisify(fn.bind(this._db));
    }
    async load() {
        let first = false;
        try {
            await fs.promises.stat(DATABASE_FILE);
        }
        catch (err) {
            first = true;
        }
        this._db = new Nedb({
            filename: DATABASE_FILE
        });
        const load = this.promise(this._db.loadDatabase);
        await load();
        if (first) {
            const insert = this.promise(this._db.insert);
            await insert({
                path: DEFAULT_HOST
            });
        }
    }
    validateHost(path) {
        const r = /^(mongodb:(?:\/{2})?)?((\w+?):(\w+?)@|:?@?)([\w\.]+?):(\d+)(\/(\w+?))?$/;
        if (!r.exec(path)) {
            throw new Error("Malformed URI");
        }
        return {
            path: (path.startsWith('mongodb://'))
                ? path.slice('mongodb://'.length)
                : path
        };
    }
    getHosts() {
        return new Promise((resolve, reject) => {
            this._db.find({}, (err, hosts) => {
                if (err) {
                    return reject(err);
                }
                else {
                    return resolve(hosts);
                }
            });
        });
    }
    async add(path) {
        const host = this.validateHost(path);
        return new Promise((resolve, reject) => {
            this._db.update({
                path: host.path
            }, {
                $set: {
                    path: host.path
                }
            }, { upsert: true }, (err) => {
                if (err) {
                    return reject(err);
                }
                else {
                    return resolve();
                }
            });
        });
    }
    async remove(path) {
        const host = this.validateHost(path);
        return new Promise((resolve, reject) => {
            this._db.remove({
                path: new RegExp(`@?${host.path}$`)
            }, (err) => {
                if (err) {
                    return reject(err);
                }
                else {
                    return resolve();
                }
            });
        });
    }
}
exports.HostsManager = HostsManager;
